@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.7.0-3
+# Application Name - Health Check V0.7.1-0
 #Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -233,20 +233,42 @@ class imagea(QtGui.QMainWindow):
 		bus = dbus.SessionBus()
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
 		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-		interface.Notify('HealthCheck', 0, 'general_refresh', 'Back Camera', 'Open your Lens Cover!!.', [], {}, 3000)
-		
-		# Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
-		b = None
-		# X-term - grab 10 buffered front camera images, and throw them into an image file.
-		# Everyone recommends 1.... but 10 gave more light! - so i used it :D
-		b = os.popen('gst-launch v4l2camsrc device=/dev/video0 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
-		b.close ()
-		# Declare and set the image file name
-		image_file = "/home/user/MyDocs/fcamtest.jpg"
-		image = QtGui.QPixmap(image_file)
-		# Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
-		self.lbl_CameraShow.setPixmap(image)
-		print " ** Finished Back camera function **"
+		interface.Notify('HealthCheck', 0, 'general_refresh', 'Back Camera', 'Checking Lens Cover and taking photo', [], {}, 3000)
+
+		gl = os.popen('cat /sys/devices/platform/gpio-switch/cam_shutter/state').read()
+		gl = gl.strip()
+
+		if str(gl) == "closed":
+                        self.CloseDialog = QtGui.QMessageBox.question(None,"WARNING - Camera Shutter is Closed"," Please open the shutter and click yes when ready. \n Click no to cancel", QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,QtGui.QMessageBox.No)
+                        if self.CloseDialog == QtGui.QMessageBox.Yes:
+                                print "** Please open the shutter and click yes when ready ** \n Click no to cancel"
+                                # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
+                                b = None
+                                # X-term - grab 10 buffered front camera images, and throw them into an image file.
+                                # Everyone recommends 1.... but 10 gave more light! - so i used it :D
+                                b = os.popen('gst-launch v4l2camsrc device=/dev/video0 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
+                                b.close ()
+                                # Declare and set the image file name
+                                image_file = "/home/user/MyDocs/fcamtest.jpg"
+                                image = QtGui.QPixmap(image_file)
+                                # Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
+                                self.lbl_CameraShow.setPixmap(image)
+                                print " ** Finished Back camera function **"
+                        elif self.CloseDialog == QtGui.QMessageBox.No:
+                                print "** User pressed 'No' button - returning **"
+		else:
+        		# Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
+                        b = None
+                        # X-term - grab 10 buffered front camera images, and throw them into an image file.
+                        # Everyone recommends 1.... but 10 gave more light! - so i used it :D
+                        b = os.popen('gst-launch v4l2camsrc device=/dev/video0 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
+                        b.close ()
+                        # Declare and set the image file name
+                        image_file = "/home/user/MyDocs/fcamtest.jpg"
+                        image = QtGui.QPixmap(image_file)
+                        # Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
+                        self.lbl_CameraShow.setPixmap(image)
+                        print " ** Finished Back camera function **"
 
 
 
@@ -377,21 +399,17 @@ class Ui_MainWindow(object):
 		self.centralwidget = QtGui.QWidget(MainWindow)
 		self.centralwidget.setObjectName("centralwidget")
 
+
 		# Draw the Menubar
 		fremantle = MainWindow.menuBar().addMenu("Update");
-		
 		act = fremantle.addAction("All")
 		QtCore.QObject.connect(act, QtCore.SIGNAL("triggered()"), self.updateAll)
-		
 		actb = fremantle.addAction("System")
 		QtCore.QObject.connect(actb, QtCore.SIGNAL("triggered()"), self.updateTab1)
-		
 		actc = fremantle.addAction("Comms")
 		QtCore.QObject.connect(actc, QtCore.SIGNAL("triggered()"), self.updateTab2)
-
 		#fremantle = MainWindow.menuBar().addMenu("Applications");
-		MainWindow.menuBar().addSeparator()
-		
+		#MainWindow.menuBar().addSeparator()
 		actd = fremantle.addAction("Apps")
 		QtCore.QObject.connect(actd, QtCore.SIGNAL("triggered()"), self.listpackages)
 
@@ -589,7 +607,7 @@ class Ui_MainWindow(object):
 		# box of some sort
 		self.textBrowser = QtGui.QTextBrowser(self.tab_5)
 		self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-		self.textBrowser.setText (" Health Check V0.7.0-3 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec(Accuracy test), Rob1n(App window) & Lcuk(Everything!)\n And to all the testers.")
+		self.textBrowser.setText (" Health Check V0.7.1-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec(Accuracy test), Rob1n(App window) & Lcuk(Everything!)\n And to all the testers.")
 		# Make the font small!!!
 		font = QtGui.QFont()
 		font.setPointSize(20)
@@ -599,11 +617,6 @@ class Ui_MainWindow(object):
 		# Draw the main Window
 		MainWindow.setCentralWidget(self.centralwidget)
 		
-		# Draw the Status bar
-		print "** Add empty lists to tab1 **"
-		self.addemptylist1(MainWindow)
-		print "** Add empty lists to tab2 **"
-		self.addemptylist2(MainWindow)
 		# Run the translate UI - Added by QT Designer - i have removed alot of setText's and placed them above.
 		print "** Run retranslateUi **"
 		self.retranslateUi(MainWindow)
@@ -643,9 +656,10 @@ class Ui_MainWindow(object):
 
                 self.listApps.clear()
                 self.checkpkgs()
+                #self.read_names()
                 self.listApps.sortItems()		
 
-	def read_names():
+	def read_names(self):
             global dpkg_dir
             global name_lookup
             pkg = ''
@@ -666,6 +680,8 @@ class Ui_MainWindow(object):
                             if pkg != full_name:
                                     name_lookup[pkg] = full_name
 
+                    self.listApps.addItem(full_name)
+
             pkg_stat.close()
 
             # Lookup the full display name for a package
@@ -831,35 +847,6 @@ class Ui_MainWindow(object):
 
 
 		
-  
-
-	def addemptylist1(self,MainWindow):
-		self.listWidget.clear()
-		self.listWidget.addItem("Firmware Version")
-		self.listWidget.addItem("Processor Information")
-		self.listWidget.addItem("N900 Board")
-		self.listWidget.addItem("System Locale")   
-		self.listWidget.addItem("Boot Count")
-		self.listWidget.addItem("FM Trans Strength")
-		self.listWidget.addItem("System Uptime")
-		self.listWidget.addItem("Battery")
-		self.listWidget.addItem("Accelerometer")
-		self.listWidget.addItem("MyDocs")
-		self.listWidget.addItem("Rootfs Free")
-		self.listWidget.sortItems()
-		print "** Empty List Added**"
-
-	def addemptylist2(self,MainWindow):
-		self.listWidget2.clear()
-		self.listWidget2.addItem("Cell ID")
-		self.listWidget2.addItem("Cell RNC")
-		self.listWidget2.addItem("Cell Services")
-		self.listWidget2.addItem("Cell Status")   
-		self.listWidget2.addItem("GPS Position")
-		self.listWidget2.addItem("Internal IP")
-		self.listWidget2.addItem("Phone signal")
-		self.listWidget2.sortItems()
-		print "** Empty List Added**"
 		
 # Funtion - update GPS - Using lib-location
 	def updateGPS(self, MainWindow):
@@ -984,9 +971,9 @@ class Ui_MainWindow(object):
 		print " ** Getting CPU Info **"
 		# This one reads fremantle version number (Firmware)
 		ga = os.popen('cat /proc/cpuinfo | grep Processor').read()
-		ga = ga.strip()[11:]
-		
+		ga = ga.strip()[11:]		
 		self.listWidget.addItem("Processor Information \t" + ga.strip())
+				
 		print " ** Getting board info**"
 		gb = os.popen('cat /proc/cpuinfo | grep Hardware').read()
 		gb = gb.strip()[11:]
@@ -1014,6 +1001,26 @@ class Ui_MainWindow(object):
 	
 		self.listWidget.addItem("FM Trans Strength \t\t" + ge.strip())
 
+		gl = os.popen('cat /proc/bootreason').read()
+		gl = gl.strip()	
+		self.listWidget.addItem("Boot Reason (last) \t\t" + gl.strip())
+
+		gl = os.popen('cat /sys/devices/platform/gpio-switch/cam_shutter/state').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Camera Shutter State \t" + gl.strip())
+
+		gl = os.popen('cat /sys/devices/platform/gpio-switch/slide/state').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Keyboard Slider State \t" + gl.strip())
+
+		gl = os.popen('cat /sys/devices/platform/gpio-switch/proximity/state').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Proximity Sensor State \t" + gl.strip())
+
+		gl = os.popen('cat /sys/devices/platform/gpio-switch/headphone/state ').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Headphone State \t\t" + gl.strip())
+
  
 		
 	def updatenetname(self):
@@ -1220,7 +1227,7 @@ class Ui_MainWindow(object):
 		
 	# This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
 	def retranslateUi(self, MainWindow):
-		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.7.0-3", None, QtGui.QApplication.UnicodeUTF8))
+		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V0.7.1-0", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Apps", None, QtGui.QApplication.UnicodeUTF8))
